@@ -67,7 +67,7 @@ static void gtk_plot_canvas_plot_button_release (GtkPlotCanvas *canvas,
 						 GtkPlotCanvasChild *child);
 static void reset_plot_allocation		(GtkPlotCanvas *canvas, 
 						 GtkPlotCanvasPlot *child);
-extern inline gint roundint                     (gdouble x);
+gint roundint                     (gdouble x);
 static GtkPlotCanvasChildClass *parent_class = NULL;
 
 extern GtkPlotCanvasPos possible_selection	(GtkAllocation area, 
@@ -146,8 +146,10 @@ static void
 gtk_plot_canvas_plot_destroy(GtkObject *object)
 {
   GtkWidget *widget = GTK_WIDGET(GTK_PLOT_CANVAS_PLOT(object)->plot);
-  g_object_unref(widget);
-  widget->parent = NULL;
+  if (widget != NULL) {
+	  widget->parent = NULL;
+	  g_object_unref(widget);
+  }
 }
 
 static void 
