@@ -9,7 +9,7 @@ char *fake = N_("Tolerance for continuity of functions and for calculating the l
 char *fake = N_("How many iterations to try to find the limit for derivative");
 char *fake = N_("How many successive steps to be within tolerance for calculation of derivative");
 char *fake = N_("Tolerance for calculating the derivatives of functions");
-char *fake = N_("Tolerance of the ErrorFunction");
+char *fake = N_("Tolerance of the ErrorFunction (used for complex values only)");
 char *fake = N_("Tolerance of the GaussDistribution function");
 char *fake = N_("The function used for numerical integration in NumericalIntegral");
 char *fake = N_("Steps to perform in NumericalIntegral");
@@ -214,7 +214,6 @@ char *fake = N_("Compute two-sided derivative using three-point formula");
 char *fake = N_("argument (angle) of complex number");
 char *fake = N_("Dirichlet kernel of order n");
 char *fake = N_("Returns 1 if and only if all elements are zero");
-char *fake = N_("The error function, 2/sqrt(pi) * int_0^x e^(-t^2) dt");
 char *fake = N_("Fejer kernel of order n");
 char *fake = N_("Returns 1 if and only if all elements are equal");
 char *fake = N_("Principal branch of the Lambert W function for real values greater than or equal to -1/e");
